@@ -1,13 +1,13 @@
 /******************************************************************************/
 /*! @file fcgiapp.cc
     @brief fcgi library.
-    @author Tachibanamasashi, Apolloron Project.
+    @author Masashi Astro Tachibana, Apolloron Project.
  ******************************************************************************/
 
 /*
  * fcgiapp.c --
  *
- *	FastCGI application library: request-at-a-time
+ *  FastCGI application library: request-at-a-time
  *
  *
  * Copyright (c) 1996 Open Market, Inc.
@@ -83,7 +83,7 @@ static char *StringCopy(const char *str)
  *      Reads a byte from the input stream and returns it.
  *
  * Results:
- *	The byte, or EOF (-1) if the end of input has been reached.
+ *  The byte, or EOF (-1) if the end of input has been reached.
  *
  *----------------------------------------------------------------------
  */
@@ -116,7 +116,7 @@ int FCGX_GetChar(FCGX_Stream *stream)
  *      of the input bytes.
  *
  * Results:
- *	Number of bytes read.  If result is smaller than n,
+ *  Number of bytes read.  If result is smaller than n,
  *      the end of input has been reached.
  *
  *----------------------------------------------------------------------
@@ -173,7 +173,7 @@ int FCGX_GetStr(char *str, int n, FCGX_Stream *stream)
  *      stores a '\0' terminator.
  *
  * Results:
- *	NULL if EOF is the first thing read from the input stream,
+ *  NULL if EOF is the first thing read from the input stream,
  *      str otherwise.
  *
  *----------------------------------------------------------------------
@@ -211,7 +211,7 @@ char *FCGX_GetLine(char *str, int n, FCGX_Stream *stream)
  *      has been read.  No pushback is possible for EOF.
  *
  * Results:
- *	Returns c if the pushback succeeded, EOF if not.
+ *  Returns c if the pushback succeeded, EOF if not.
  *
  *----------------------------------------------------------------------
  */
@@ -240,7 +240,7 @@ int FCGX_UnGetChar(int c, FCGX_Stream *stream) {
  *      ability to peek ahead.
  *
  * Results:
- *	EOF if end-of-file has been detected, 0 if not.
+ *  EOF if end-of-file has been detected, 0 if not.
  *
  *----------------------------------------------------------------------
  */
@@ -256,7 +256,7 @@ int FCGX_HasSeenEOF(FCGX_Stream *stream) {
  *      Writes a byte to the output stream.
  *
  * Results:
- *	The byte, or EOF (-1) if an error occurred.
+ *  The byte, or EOF (-1) if an error occurred.
  *
  *----------------------------------------------------------------------
  */
@@ -313,7 +313,7 @@ int FCGX_PutStr(const char *str, int n, FCGX_Stream *stream)
             if(bytesMoved == n)
                 return bytesMoved;
             str += m;
-	}
+        }
         if(stream->isClosed || stream->isReader)
             return -1;
         stream->emptyBuffProc(stream, FALSE);
@@ -378,14 +378,14 @@ int FCGX_FPrintF(FCGX_Stream *stream, const char *format, ...)
  */
 
 #define PRINTF_BUFFLEN 100
-    /*
-     * More than sufficient space for all unmodified conversions
-     * except %s and %f.
-     */
+/*
+ * More than sufficient space for all unmodified conversions
+ * except %s and %f.
+ */
 #define FMT_BUFFLEN 25
-    /*
-     * Max size of a format specifier is 1 + 5 + 7 + 7 + 2 + 1 + slop
-     */
+/*
+ * Max size of a format specifier is 1 + 5 + 7 + 7 + 2 + 1 + slop
+ */
 static void CopyAndAdvance(char **destPtr, char **srcPtr, int n);
 
 int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
@@ -424,7 +424,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
             streamCount += percentPtr - f;
             f = percentPtr;
             if(f == fStop) break;
-	}
+        }
         fastPath = TRUE;
         /*
          * The following loop always executes either once or twice.
@@ -444,8 +444,8 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                  */
                 op = *(percentPtr + 1);
                 switch(op) {
-	            case 'l':
-	            case 'L':
+                    case 'l':
+                    case 'L':
                     case 'h':
                         sizeModifier = op;
                         op = *(percentPtr + 2);
@@ -454,16 +454,16 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                         fmtBuff[3] = '\0';
                         specifierLength = 3;
                         break;
-	            default:
+                    default:
                         sizeModifier = ' ';
                         fmtBuff[1] = (char) op;
                         fmtBuff[2] = '\0';
                         specifierLength = 2;
                         break;
-	        }
+                }
                 buffPtr = buff;
                 buffLen = PRINTF_BUFFLEN;
-	    } else {
+            } else {
                 /*
                  * Slow path: Scan the conversion specifier and construct
                  * a new format string, compute an upper bound on the
@@ -488,18 +488,18 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                         minWidth = va_arg(arg, int);
                         if(abs(minWidth) > 999999)
                             goto ErrorReturn;
-			/*
-			 * The following use of strlen rather than the
-			 * value returned from sprintf is because SUNOS4
-			 * returns a char * instead of an int count.
-			 */
-			sprintf(fmtBuffPtr, "%d", minWidth);
+                        /*
+                         * The following use of strlen rather than the
+                         * value returned from sprintf is because SUNOS4
+                         * returns a char * instead of an int count.
+                         */
+                        sprintf(fmtBuffPtr, "%d", minWidth);
                         fmtBuffPtr += strlen(fmtBuffPtr);
                         p++;
-	            } else {
+                    } else {
                         minWidth = 0;
-	            }
-	        } else if(n <= 6) {
+                    }
+                } else if(n <= 6) {
                     minWidth = strtol(p, NULL, 10);
                     CopyAndAdvance(&fmtBuffPtr, &p, n);
                 } else {
@@ -508,7 +508,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                 /*
                  * Scan precision
                  */
-	        if(*p == '.') {
+                if(*p == '.') {
                     CopyAndAdvance(&fmtBuffPtr, &p, 1);
                     n = strspn(p, "0123456789");
                     if(n == 0) {
@@ -517,18 +517,18 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                             if(precision < 0) precision = 0;
                             if(precision > 999999)
                                 goto ErrorReturn;
-			/*
-			 * The following use of strlen rather than the
-			 * value returned from sprintf is because SUNOS4
-			 * returns a char * instead of an int count.
-			 */
-			    sprintf(fmtBuffPtr, "%d", precision);
-			    fmtBuffPtr += strlen(fmtBuffPtr);
+                            /*
+                             * The following use of strlen rather than the
+                             * value returned from sprintf is because SUNOS4
+                             * returns a char * instead of an int count.
+                             */
+                            sprintf(fmtBuffPtr, "%d", precision);
+                            fmtBuffPtr += strlen(fmtBuffPtr);
                             p++;
-	                } else {
+                        } else {
                             precision = 0;
-	                }
-	            } else if(n <= 6) {
+                        }
+                    } else if(n <= 6) {
                         precision = strtol(p, NULL, 10);
                         CopyAndAdvance(&fmtBuffPtr, &p, n);
                     } else {
@@ -541,13 +541,13 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                  * Scan size modifier and conversion operation
                  */
                 switch(*p) {
-	            case 'l':
+                    case 'l':
                     case 'L':
                     case 'h':
                         sizeModifier = *p;
                         CopyAndAdvance(&fmtBuffPtr, &p, 1);
                         break;
-	            default:
+                    default:
                         sizeModifier = ' ';
                         break;
                 }
@@ -560,7 +560,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                  * conversions this requires examining the argument.
                  */
                 switch(op) {
-	            case 'd':
+                    case 'd':
                     case 'i':
                     case 'u':
                     case 'o':
@@ -570,28 +570,28 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                     case 'p':
                         buffReqd = max(precision, 46);
                         break;
-	            case 's':
+                    case 's':
                         charPtrArg = va_arg(arg, char *);
-			if (!charPtrArg) charPtrArg = "(null)";
+                        if (!charPtrArg) charPtrArg = "(null)";
                         if(precision == -1) {
-			    buffReqd = strlen(charPtrArg);
-		        } else {
-			    p = (char *)memchr(charPtrArg, '\0', precision);
+                            buffReqd = strlen(charPtrArg);
+                        } else {
+                            p = (char *)memchr(charPtrArg, '\0', precision);
                             buffReqd =
-			      (p == NULL) ? precision : p - charPtrArg;
-			}
+                                (p == NULL) ? precision : p - charPtrArg;
+                        }
                         break;
-	            case 'f':
+                    case 'f':
                         switch(sizeModifier) {
                             case ' ':
                                 doubleArg = va_arg(arg, double);
-				                frexp(doubleArg, &exp);
+                                frexp(doubleArg, &exp);
                                 break;
                             case 'L':
                                 lDoubleArg = va_arg(arg, LONG_DOUBLE);
-                                /* XXX Need to check for the presence of 
+                                /* XXX Need to check for the presence of
                                  * frexpl() and use it if available */
-				                frexp((double) lDoubleArg, &exp);
+                                frexp((double) lDoubleArg, &exp);
                                 break;
                             default:
                                 goto ErrorReturn;
@@ -599,16 +599,16 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                         if(precision == -1) precision = 6;
                         buffReqd = precision + 3 + ((exp > 0) ? exp/3 : 0);
                         break;
-	            case 'e':
-	            case 'E':
-	            case 'g':
-	            case 'G':
+                    case 'e':
+                    case 'E':
+                    case 'g':
+                    case 'G':
                         if(precision == -1) precision = 6;
                         buffReqd = precision + 8;
                         break;
-	            case 'n':
-	            case '%':
-	            default:
+                    case 'n':
+                    case '%':
+                    default:
                         goto ErrorReturn;
                         break;
                 }
@@ -616,21 +616,21 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                 /*
                  * Allocate the buffer
                  */
-	        if(buffReqd <= PRINTF_BUFFLEN) {
+                if(buffReqd <= PRINTF_BUFFLEN) {
                     buffPtr = buff;
-		    buffLen = PRINTF_BUFFLEN;
-	        } else {
+                    buffLen = PRINTF_BUFFLEN;
+                } else {
                     if(auxBuffPtr == NULL || buffReqd > auxBuffLen) {
-		        if(auxBuffPtr != NULL) free(auxBuffPtr);
+                        if(auxBuffPtr != NULL) free(auxBuffPtr);
                         auxBuffPtr = (char *)Malloc(buffReqd);
                         auxBuffLen = buffReqd;
                         if(auxBuffPtr == NULL)
                             goto ErrorReturn;
-		    }
+                    }
                     buffPtr = auxBuffPtr;
-		    buffLen = auxBuffLen;
-		}
-	    }
+                    buffLen = auxBuffLen;
+                }
+            }
             /*
              * This giant switch statement requires the following variables
              * to be set up: op, sizeModifier, arg, buffPtr, fmtBuff.
@@ -646,41 +646,41 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
              */
             performedOp = TRUE;
             switch(op) {
-	        case 'd':
-	        case 'i':
+                case 'd':
+                case 'i':
                     switch(sizeModifier) {
                         case ' ':
                             intArg = va_arg(arg, int);
-			    sprintf(buffPtr, fmtBuff, intArg);
+                            sprintf(buffPtr, fmtBuff, intArg);
                             buffCount = strlen(buffPtr);
                             break;
-	                case 'l':
+                        case 'l':
                             longArg = va_arg(arg, long);
                             sprintf(buffPtr, fmtBuff, longArg);
                             buffCount = strlen(buffPtr);
                             break;
-	                case 'h':
+                        case 'h':
                             shortArg = (short) va_arg(arg, int);
                             sprintf(buffPtr, fmtBuff, shortArg);
                             buffCount = strlen(buffPtr);
                             break;
-	                default:
+                        default:
                             goto ErrorReturn;
-	            }
+                    }
                     break;
-	        case 'u':
+                case 'u':
                 case 'o':
                 case 'x':
                 case 'X':
                     switch(sizeModifier) {
                         case ' ':
                             unsignedArg = va_arg(arg, unsigned);
-			    sprintf(buffPtr, fmtBuff, unsignedArg);
+                            sprintf(buffPtr, fmtBuff, unsignedArg);
                             buffCount = strlen(buffPtr);
                             break;
-	                case 'l':
+                        case 'l':
                             uLongArg = va_arg(arg, unsigned long);
-			    sprintf(buffPtr, fmtBuff, uLongArg);
+                            sprintf(buffPtr, fmtBuff, uLongArg);
                             buffCount = strlen(buffPtr);
                             break;
                         case 'h':
@@ -696,32 +696,32 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                     switch(sizeModifier) {
                         case ' ':
                             intArg = va_arg(arg, int);
-			    sprintf(buffPtr, fmtBuff, intArg);
+                            sprintf(buffPtr, fmtBuff, intArg);
                             buffCount = strlen(buffPtr);
                             break;
-	                case 'l':
+                        case 'l':
                             /*
                              * XXX: Allowed by ISO C Amendment 1, but
                              * many platforms don't yet support wint_t
                              */
                             goto ErrorReturn;
-                    default:
+                        default:
                             goto ErrorReturn;
                     }
                     break;
-	        case 's':
+                case 's':
                     switch(sizeModifier) {
                         case ' ':
-		            if(fastPath) {
-			        buffPtr = va_arg(arg, char *);
+                            if(fastPath) {
+                                buffPtr = va_arg(arg, char *);
                                 buffCount = strlen(buffPtr);
                                 buffLen = buffCount + 1;
-			    } else {
-				sprintf(buffPtr, fmtBuff, charPtrArg);
-	                        buffCount = strlen(buffPtr);
-			    }
-			    break;
-	                case 'l':
+                            } else {
+                                sprintf(buffPtr, fmtBuff, charPtrArg);
+                                buffCount = strlen(buffPtr);
+                            }
+                            break;
+                        case 'l':
                             /*
                              * XXX: Don't know how to convert a sequence
                              * of wide characters into a byte stream, or
@@ -736,7 +736,7 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                     if(sizeModifier != ' ')
                         goto ErrorReturn;
                     voidPtrArg = va_arg(arg, void *);
-		    sprintf(buffPtr, fmtBuff, voidPtrArg);
+                    sprintf(buffPtr, fmtBuff, voidPtrArg);
                     buffCount = strlen(buffPtr);
                     break;
                 case 'n':
@@ -753,23 +753,23 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                             shortPtrArg = (short *) va_arg(arg, short *);
                             *shortPtrArg = (short) streamCount;
                             break;
-	                default:
+                        default:
                             goto ErrorReturn;
-	            }
+                    }
                     buffCount = 0;
                     break;
                 case 'f':
-		    if(fastPath) {
-		        performedOp = FALSE;
+                    if(fastPath) {
+                        performedOp = FALSE;
                         break;
-		    }
+                    }
                     switch(sizeModifier) {
                         case ' ':
-			    sprintf(buffPtr, fmtBuff, doubleArg);
+                            sprintf(buffPtr, fmtBuff, doubleArg);
                             buffCount = strlen(buffPtr);
                             break;
                         case 'L':
-			    sprintf(buffPtr, fmtBuff, lDoubleArg);
+                            sprintf(buffPtr, fmtBuff, lDoubleArg);
                             buffCount = strlen(buffPtr);
                             break;
                         default:
@@ -783,12 +783,12 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
                     switch(sizeModifier) {
                         case ' ':
                             doubleArg = va_arg(arg, double);
-			    sprintf(buffPtr, fmtBuff, doubleArg);
+                            sprintf(buffPtr, fmtBuff, doubleArg);
                             buffCount = strlen(buffPtr);
                             break;
                         case 'L':
                             lDoubleArg = va_arg(arg, LONG_DOUBLE);
-			    sprintf(buffPtr, fmtBuff, lDoubleArg);
+                            sprintf(buffPtr, fmtBuff, lDoubleArg);
                             buffCount = strlen(buffPtr);
                             break;
                         default:
@@ -818,13 +818,13 @@ int FCGX_VFPrintF(FCGX_Stream *stream, const char *format, va_list arg)
             streamCount += buffCount;
         } else if(buffCount < 0) {
             goto ErrorReturn;
-	}
+        }
         f += specifierLength;
     } /* while(f != fStop) */
     goto NormalReturn;
-  ErrorReturn:
+ErrorReturn:
     streamCount = -1;
-  NormalReturn:
+NormalReturn:
     if(auxBuffPtr != NULL) free(auxBuffPtr);
     return streamCount;
 }
@@ -925,7 +925,7 @@ static void SetError(FCGX_Stream *stream, int FCGI_errno)
     if(stream->FCGI_errno == 0) {
         stream->FCGI_errno = FCGI_errno;
     }
-  
+
     stream->isClosed = TRUE;
 }
 
@@ -981,8 +981,8 @@ void FCGX_ClearError(FCGX_Stream *stream) {
 
 typedef struct Params {
     FCGX_ParamArray vec;    /* vector of strings */
-    int length;		    /* number of string vec can hold */
-    char **cur;		    /* current item in vec; *cur == NULL */
+    int length;         /* number of string vec can hold */
+    char **cur;         /* current item in vec; *cur == NULL */
 } Params;
 typedef Params *ParamsPtr;
 
@@ -991,7 +991,7 @@ typedef Params *ParamsPtr;
  *
  * NewParams --
  *
- *	Creates a new Params structure.
+ *  Creates a new Params structure.
  *
  * Results:
  *      Pointer to the new structure.
@@ -1014,7 +1014,7 @@ static ParamsPtr NewParams(int length)
  *
  * FreeParams --
  *
- *	Frees a Params structure and all the parameters it contains.
+ *  Frees a Params structure and all the parameters it contains.
  *
  * Side effects:
  *      env becomes invalid.
@@ -1041,7 +1041,7 @@ static void FreeParams(ParamsPtr *paramsPtrPtr)
  *
  * PutParam --
  *
- *	Add a name/value pair to a Params structure.
+ *  Add a name/value pair to a Params structure.
  *
  * Results:
  *      None.
@@ -1058,9 +1058,9 @@ static void PutParam(ParamsPtr paramsPtr, char *nameValue)
     *paramsPtr->cur++ = nameValue;
     size = paramsPtr->cur - paramsPtr->vec;
     if(size >= paramsPtr->length) {
-	paramsPtr->length *= 2;
-	paramsPtr->vec = (FCGX_ParamArray)realloc(paramsPtr->vec, paramsPtr->length * sizeof(char *));
-	paramsPtr->cur = paramsPtr->vec + size;
+        paramsPtr->length *= 2;
+        paramsPtr->vec = (FCGX_ParamArray)realloc(paramsPtr->vec, paramsPtr->length * sizeof(char *));
+        paramsPtr->cur = paramsPtr->vec + size;
     }
     *paramsPtr->cur = NULL;
 }
@@ -1072,7 +1072,7 @@ static void PutParam(ParamsPtr paramsPtr, char *nameValue)
  *
  *
  * Results:
- *	Value bound to name, NULL if name not present in the
+ *  Value bound to name, NULL if name not present in the
  *      environment envp.  Caller must not mutate the result
  *      or retain it past the end of this request.
  *
@@ -1083,7 +1083,7 @@ char *FCGX_GetParam(const char *name, FCGX_ParamArray envp)
     int len;
     char **p;
 
-	if (name == NULL || envp == NULL) return NULL;
+    if (name == NULL || envp == NULL) return NULL;
 
     len = strlen(name);
 
@@ -1128,21 +1128,21 @@ static int ReadParams(Params *paramsPtr, FCGX_Stream *stream)
             if(FCGX_GetStr((char *) &lenBuff[0], 3, stream) != 3) {
                 SetError(stream, FCGX_PARAMS_ERROR);
                 return -1;
-	    }
+            }
             nameLen = ((nameLen & 0x7f) << 24) + (lenBuff[0] << 16)
-                    + (lenBuff[1] << 8) + lenBuff[2];
+                      + (lenBuff[1] << 8) + lenBuff[2];
         }
         if((valueLen = FCGX_GetChar(stream)) == EOF) {
             SetError(stream, FCGX_PARAMS_ERROR);
             return -1;
-	}
+        }
         if((valueLen & 0x80) != 0) {
             if(FCGX_GetStr((char *) &lenBuff[0], 3, stream) != 3) {
                 SetError(stream, FCGX_PARAMS_ERROR);
                 return -1;
-	    }
+            }
             valueLen = ((valueLen & 0x7f) << 24) + (lenBuff[0] << 16)
-                    + (lenBuff[1] << 8) + lenBuff[2];
+                       + (lenBuff[1] << 8) + lenBuff[2];
         }
         /*
          * nameLen and valueLen are now valid; read the name and value
@@ -1153,14 +1153,14 @@ static int ReadParams(Params *paramsPtr, FCGX_Stream *stream)
             SetError(stream, FCGX_PARAMS_ERROR);
             free(nameValue);
             return -1;
-	}
+        }
         *(nameValue + nameLen) = '=';
         if(FCGX_GetStr(nameValue + nameLen + 1, valueLen, stream)
                 != valueLen) {
             SetError(stream, FCGX_PARAMS_ERROR);
             free(nameValue);
             return -1;
-	}
+        }
         *(nameValue + nameLen + valueLen + 1) = '\0';
         PutParam(paramsPtr, nameValue);
     }
@@ -1177,10 +1177,10 @@ static int ReadParams(Params *paramsPtr, FCGX_Stream *stream)
  *----------------------------------------------------------------------
  */
 static FCGI_Header MakeHeader(
-        int type,
-        int requestId,
-        int contentLength,
-        int paddingLength)
+    int type,
+    int requestId,
+    int contentLength,
+    int paddingLength)
 {
     FCGI_Header header;
     header.version = FCGI_VERSION_1;
@@ -1204,8 +1204,8 @@ static FCGI_Header MakeHeader(
  *----------------------------------------------------------------------
  */
 static FCGI_EndRequestBody MakeEndRequestBody(
-        int appStatus,
-        int protocolStatus)
+    int appStatus,
+    int protocolStatus)
 {
     FCGI_EndRequestBody body;
     body.appStatusB3    = (unsigned char) ((appStatus >> 24) & 0xff);
@@ -1227,7 +1227,7 @@ static FCGI_EndRequestBody MakeEndRequestBody(
  *----------------------------------------------------------------------
  */
 static FCGI_UnknownTypeBody MakeUnknownTypeBody(
-        int type)
+    int type)
 {
     FCGI_UnknownTypeBody body;
     body.type = (unsigned char) type;
@@ -1323,12 +1323,12 @@ static void WriteCloseRecords(struct FCGX_Stream *stream)
     if(data->reqDataPtr->nWriters == 1) {
         FCGI_EndRequestRecord endRequestRecord;
         endRequestRecord.header = MakeHeader(FCGI_END_REQUEST,
-                data->reqDataPtr->requestId,
-                sizeof(endRequestRecord.body), 0);
+                                             data->reqDataPtr->requestId,
+                                             sizeof(endRequestRecord.body), 0);
         endRequestRecord.body = MakeEndRequestBody(
-                data->reqDataPtr->appStatus, FCGI_REQUEST_COMPLETE);
+                                    data->reqDataPtr->appStatus, FCGI_REQUEST_COMPLETE);
         FCGX_PutStr((char *) &endRequestRecord,
-                sizeof(endRequestRecord), stream);
+                    sizeof(endRequestRecord), stream);
     }
     data->reqDataPtr->nWriters--;
 }
@@ -1380,11 +1380,11 @@ static void EmptyBuffProc(struct FCGX_Stream *stream, int doClose)
             memset(stream->wrNext, 0, eLen - cLen);
             stream->wrNext += eLen - cLen;
             *((FCGI_Header *) data->buff)
-                    = MakeHeader(data->type,
-                            data->reqDataPtr->requestId, cLen, eLen - cLen);
+                = MakeHeader(data->type,
+                             data->reqDataPtr->requestId, cLen, eLen - cLen);
         } else {
             stream->wrNext = data->buff;
-	}
+        }
     }
     if(doClose) {
         WriteCloseRecords(stream);
@@ -1458,7 +1458,7 @@ static int ProcessManagementRecord(int type, FCGX_Stream *stream)
                 len = strlen(name);
                 sprintf(responseP, "%c%c%s%c", len, 1, name, value);
                 responseP += len + 3;
-	    }
+            }
         }
         len = responseP - &response[FCGI_HEADER_LEN];
         paddedLen = AlignInt8(len);
@@ -1515,9 +1515,9 @@ static int ProcessBeginRecord(int requestId, FCGX_Stream *stream)
          */
         FCGI_EndRequestRecord endRequestRecord;
         endRequestRecord.header = MakeHeader(FCGI_END_REQUEST,
-                requestId, sizeof(endRequestRecord.body), 0);
+                                             requestId, sizeof(endRequestRecord.body), 0);
         endRequestRecord.body
-                = MakeEndRequestBody(0, FCGI_CANT_MPX_CONN);
+            = MakeEndRequestBody(0, FCGI_CANT_MPX_CONN);
         if (write_it_all(data->reqDataPtr->ipcFd, (char *)&endRequestRecord, sizeof(endRequestRecord)) < 0) {
             SetError(stream, OS_Errno);
             return -1;
@@ -1569,9 +1569,9 @@ static int ProcessHeader(FCGI_Header header, FCGX_Stream *stream)
         return FCGX_UNSUPPORTED_VERSION;
     }
     requestId =        (header.requestIdB1 << 8)
-                         + header.requestIdB0;
+                       + header.requestIdB0;
     data->contentLen = (header.contentLengthB1 << 8)
-                         + header.contentLengthB0;
+                       + header.contentLengthB0;
     data->paddingLen = header.paddingLength;
     if(header.type == FCGI_BEGIN_REQUEST) {
         return ProcessBeginRecord(requestId, stream);
@@ -1617,7 +1617,7 @@ static void FillBuffProc(FCGX_Stream *stream)
             }
             stream->rdNext = data->buff;
             data->buffStop = data->buff + count;
-	}
+        }
         /*
          * Now data->buff is not empty.  If the current record contains
          * more content bytes, deliver all that are present in data->buff.
@@ -1628,15 +1628,15 @@ static void FillBuffProc(FCGX_Stream *stream)
             if(!data->skip) {
                 stream->wrNext = stream->stop = stream->rdNext + count;
                 return;
-	    } else {
+            } else {
                 stream->rdNext += count;
                 if(data->contentLen > 0) {
                     continue;
-	        } else {
+                } else {
                     data->skip = FALSE;
-	        }
-	    }
-	}
+                }
+            }
+        }
         /*
          * If the current record (whose content has been fully consumed by
          * the client) was padded, skip over the padding bytes.
@@ -1647,8 +1647,8 @@ static void FillBuffProc(FCGX_Stream *stream)
             stream->rdNext += count;
             if(data->paddingLen > 0) {
                 continue;
-	    }
-	}
+            }
+        }
         /*
          * All done with the current record, including the padding.
          * If we're in a recursive call from ProcessHeader, deliver EOF.
@@ -1662,13 +1662,13 @@ static void FillBuffProc(FCGX_Stream *stream)
          * Fill header with bytes from the input buffer.
          */
         count = min((int)sizeof(header) - headerLen,
-                        data->buffStop - stream->rdNext);
+                    data->buffStop - stream->rdNext);
         memcpy(((char *)(&header)) + headerLen, stream->rdNext, count);
         headerLen += count;
         stream->rdNext += count;
         if((unsigned int)headerLen < sizeof(header)) {
             continue;
-	};
+        };
         headerLen = 0;
         /*
          * Interpret header.  eorStop prevents ProcessHeader from reading
@@ -1694,9 +1694,9 @@ static void FillBuffProc(FCGX_Stream *stream)
                     stream->wrNext = stream->stop = stream->rdNext;
                     stream->isClosed = TRUE;
                     return;
-	        }
+                }
                 break;
-	    case SKIP:
+            case SKIP:
                 data->skip = TRUE;
                 break;
             case BEGIN_RECORD:
@@ -1712,7 +1712,7 @@ static void FillBuffProc(FCGX_Stream *stream)
                 SetError(stream, status);
                 return;
                 break;
-	}
+        }
     }
 }
 
@@ -1727,7 +1727,7 @@ static void FillBuffProc(FCGX_Stream *stream)
  *----------------------------------------------------------------------
  */
 static FCGX_Stream *NewStream(
-        FCGX_Request *reqDataPtr, int bufflen, int isReader, int streamType)
+    FCGX_Request *reqDataPtr, int bufflen, int isReader, int streamType)
 {
     /*
      * XXX: It would be a lot cleaner to have a NewStream that only
@@ -1874,10 +1874,10 @@ static FCGX_Stream *NewWriter(FCGX_Request *reqDataPtr, int bufflen, int streamT
  *----------------------------------------------------------------------
  */
 FCGX_Stream *FCGX_CreateWriter(
-        int ipcFd,
-        int requestId,
-        int bufflen,
-        int streamType)
+    int ipcFd,
+    int requestId,
+    int bufflen,
+    int streamType)
 {
     FCGX_Request *reqDataPtr = (FCGX_Request *)Malloc(sizeof(FCGX_Request));
     reqDataPtr->ipcFd = ipcFd;
@@ -1988,7 +1988,7 @@ void FCGX_Finish_r(FCGX_Request *reqDataPtr)
         close |= FCGX_FClose(reqDataPtr->err);
         close |= FCGX_FClose(reqDataPtr->out);
 
-	close |= FCGX_GetError(reqDataPtr->in);
+        close |= FCGX_GetError(reqDataPtr->in);
     }
 
     FCGX_Free(reqDataPtr, close);
@@ -1996,7 +1996,7 @@ void FCGX_Finish_r(FCGX_Request *reqDataPtr)
 
 void FCGX_Free(FCGX_Request * request, int close)
 {
-    if (request == NULL) 
+    if (request == NULL)
         return;
 
     FCGX_FreeStream(&request->in);
@@ -2044,7 +2044,7 @@ int FCGX_InitRequest(FCGX_Request *request, int sock, int flags)
  *      but must be called by the user when using FCGX_Accept_r().
  *
  * Results:
- *	    0 for successful call.
+ *      0 for successful call.
  *
  *----------------------------------------------------------------------
  */
@@ -2077,7 +2077,7 @@ int FCGX_Init(void)
  *      Accepts a new request from the HTTP server.
  *
  * Results:
- *	0 for successful call, -1 for error.
+ *  0 for successful call, -1 for error.
  *
  * Side effects:
  *
@@ -2098,10 +2098,10 @@ int FCGX_Init(void)
  */
 
 int FCGX_Accept(
-        FCGX_Stream **in,
-        FCGX_Stream **out,
-        FCGX_Stream **err,
-        FCGX_ParamArray *envp)
+    FCGX_Stream **in,
+    FCGX_Stream **out,
+    FCGX_Stream **err,
+    FCGX_ParamArray *envp)
 {
     int rc;
 
@@ -2130,7 +2130,7 @@ int FCGX_Accept(
  *      Accepts a new request from the HTTP server.
  *
  * Results:
- *	0 for successful call, -1 for error.
+ *  0 for successful call, -1 for error.
  *
  * Side effects:
  *
